#!/usr/bin/env perl
use strict;
use warnings;
use utf8;
use autodie;
use PerlIO::gzip;

sub say {
    my $line = shift;
    print "$line\n";
}

sub tsvsay {
    my $line = join "\t", @_;
    print "$line\n";
}

binmode STDIN, ':utf8';
binmode STDOUT, ':utf8';
binmode STDERR, ':utf8';

{
    # I want my arguments to be UTF-8
    use I18N::Langinfo qw(langinfo CODESET);
    use Encode qw(decode);
    my $codeset = langinfo(CODESET);
    @ARGV = map { decode $codeset, $_ } @ARGV;
}

if ( @ARGV < 2 ) {
    die("Usage: $0 parsed.conll gold.conll [column] \n column defaults to 7 (1-based)");
}

my $column = @ARGV >= 3 ? $ARGV[2]-1 : 7-1;

my $good = 0;
my $bad = 0;

{
    open my $parsed, '<:utf8', $ARGV[0];
    open my $gold, '<:utf8', $ARGV[1];
    my $line_p;
    my $line_g;
    while ($line_p = <$parsed>) {
        chomp $line_p;
        $line_g = <$gold>;
        chomp $line_g;
        my @fields_p = split /\t/, $line_p;
        my @fields_g = split /\t/, $line_g;
        if ( @fields_g <= $column ) {
            next;
        }
        if ( $fields_p[$column] eq $fields_g[$column] ) {
            $good++;
        } else {
            $bad++;
        }
    }
    close $parsed;
    close $gold;
}

#say ("UA SCORE: " . ($good/($good+$bad)*100) . "%");
say ($good/($good+$bad)*100);

