#!/usr/bin/env perl
use strict;
use warnings;
use utf8;
use autodie;
use PerlIO::gzip;

sub say {
    my $line = shift;
    print "$line\n";
}

sub tsvsay {
    my $line = join "\t", @_;
    print "$line\n";
}

binmode STDIN, ':utf8';
binmode STDOUT, ':utf8';
binmode STDERR, ':utf8';

{
    # I want my arguments to be UTF-8
    use I18N::Langinfo qw(langinfo CODESET);
    use Encode qw(decode);
    my $codeset = langinfo(CODESET);
    @ARGV = map { decode $codeset, $_ } @ARGV;
}

if ( @ARGV < 2 ) {
    die("Usage: $0 parsed.conll gold.conll [pos_column [parent_column]] \n pos_column defaults to 4, parent_column defaults to 7 (1-based)");
}

my $pos_column = @ARGV >= 3 ? $ARGV[2]-1 : 4-1;
my $parent_column = @ARGV >= 4 ? $ARGV[3]-1 : 7-1;

my $all;
my $good = 0;

my %all_pos = ();
my %good_pos = ();

{
    open my $parsed, '<:utf8', $ARGV[0];
    open my $gold, '<:utf8', $ARGV[1];
    my $line_p;
    my $line_g;
    while ($line_p = <$parsed>) {
        chomp $line_p;
        $line_g = <$gold>;
        chomp $line_g;
        my @fields_p = split /\t/, $line_p;
        my @fields_g = split /\t/, $line_g;
        if ( @fields_g <= $parent_column ) {
            next;
        }
        
        my $pos = $fields_g[$pos_column];
        if ($pos eq '.') {
            next;
        }

        $all++;
        $all_pos{$pos}++;
        
        if ( $fields_p[$parent_column] eq $fields_g[$parent_column] ) {
            $good++;
            $good_pos{$pos}++;
        }
    }
    close $parsed;
    close $gold;
}

#my @poses = sort {$a cmp $b} keys %all_pos;
#foreach my $pos (@poses) {
#    tsvsay ( $pos, 100*$good_pos{$pos}/$all_pos{$pos} );
#}

#warn ("total UAS: " . (100*$good/$all) . "% \n");
say (100*$good/$all);

